import Vue from 'vue'
import App from './App.vue'
import store from '@/store'
// import i18n from '@/util/lang/lang'

import Invite from '@/components/popup/invite'
import Avatar from '@/components/popup/avatar'
import Info from '@/components/popup/userInfo'
import otherInfo from '@/components/popup/otherInfo'
import imgPreview from '@/components/popup/imgPreview'
import packetGet from '@/components/popup/packetGet'
import Toast from '@/components/popup/toast'
import VueClipboard from 'vue-clipboard2'
import directive from '@/plugins/directive'
import TWEEN from '@tweenjs/tween.js'
import { register } from 'register-service-worker'

Vue.use(Invite, store)
Vue.use(Avatar, store)
Vue.use(Info, store)
Vue.use(otherInfo, store)
Vue.use(packetGet, store)
Vue.use(Toast)
Vue.use(VueClipboard)
Vue.use(directive)
Vue.use(imgPreview)

Vue.config.productionTip = false

new Vue({
  render: h => h(App),
  store
  // i18n
}).$mount('#app')

// Setup the animation loop.
function animate (time) {
  requestAnimationFrame(animate)
  TWEEN.update(time)
}
requestAnimationFrame(animate)

if (process.env.NODE_ENV === 'production') {
  register(`${process.env.BASE_URL}sw.js`, {
    ready () {
      console.log(
        'App is being served from cache by a service worker.\n' +
        'For more details, visit https://goo.gl/AFskqB'
      )
    },
    registered () {
      console.log('Service worker has been registered.')
    },
    cached () {
      console.log('Content has been cached for offline use.')
    },
    updatefound () {
      console.log('New content is downloading.')
    },
    updated () {
      console.log('New content is available; please refresh.')
    },
    offline () {
      console.log('No internet connection found. App is running in offline mode.')
    },
    error (error) {
      console.error('Error during service worker registration:', error)
    }
  })
}
